;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xaa691b64ff7ce029319f5dc13f170e3e . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x92833a809f5a3ed95995bb78fcdfc443 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xaa3a8b952f3cdc41f1e1a1fe828d18f7 . "./code.cg2js/cg-toolbar.fasl")
(#xbac76d8f531248176f2d19086ea8eb3c . "./code.cg2js/cg-chart-or-plot.fasl")
(#x7eaf487498668a85d62bfd9be1a2de15 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xc23ed68e02ce8e459526ee7dbc8348e9 . "./code.cg2js/cg-class-grid.fasl")
(#xe544d3c3fa846ab87d8ecaffefaffca6 . "./code.cg2js/cg-tray.fasl")
(#x34c85b4439253bad53a3b8e1eba68141 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x113568c3984efb2aa4c34f64204c54af . "./code.cg2js/cg-class-support.fasl")
(#x9924a0cb3725363a81a3e5c6a5ade0c8 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x5b5f4e29d7f28ebb435e346b6a64f4a3 . "./code.cg2js/cg-dropping-outline.fasl")
(#xde2b499930b373cf58f8c9fc245c0b4a . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x6ad6c608e14325af491e493ae3858a90 . "./code.cg2js/cg-choice-list.fasl")
(#xbdd89dc35638bd615e1899ded40c4089 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x63cc36b6b624010495bce14d7735fe4f . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x7b74d2c5524a842fe64a3857bf78b3f1 . "./code.cg2js/cg-timer.fasl")
(#xfaab8db8ffdbcd02c4bf512b05bdfe30 . "./code.cg2js/cg-directory-dialog.fasl")
(#x712936daddd337f5e88c569a1d90beab . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x65be8bee048ebdd27d82a2f0fdd70fed . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xdc3dd1dc3afb6f46c6f4ccc19b650071 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x741f451088c4063b39447c0c47bb37e5 . "./code.cg2js/cg-html-widget.fasl")
(#xbce63708dd1a2c0acf444ab819527682 . "./code.cg2js/cg-selected-object.fasl")
(#x1af9e1f4a4ea4ccd93329d454eb8f705 . "./code.cg2js/cg-lamp.fasl")
(#x9bcb1bc42b78a178678953864ab030d1 . "./code.cg2js/cg-scroll-bar.fasl")
(#x076de41ae280fc09d129f47c2c0d77c9 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x08313fdd28459960fb4f5c357581e214 . "./code.cg2js/cg-message-dialog.fasl")
(#xfee9f15071f7a9d03bc6cd7f487a54ac . "./code.cg2js/cg-dde-utils.fasl")
(#xaf895ffce9654ad11e015ad21d32b170 . "./code.cg2js/cg-group-box.fasl")
(#xf257f6505d3811c2fdff89c8dff7e802 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xaaeb226d0aaab9c8288ef9db9324fbbe . "./code.cg2js/cg-split-bar.fasl")
(#x4e100e7f1cf433c159e3dc09665bbe85 . "./code.cg2js/cg-radio-button.fasl")
(#x9b018d995ca1a0ac45fbbf2464b7f18d . "./code.cg2js/cg-base.fasl")
(#x2da4bf45d1576e027bdad98080645f4a . "./code.cg2js/cg-paren-matching.fasl")
(#xdb673f3726f3fe8c80ec74376dd4f4ce . "./code.cg2js/cg-graphics-context.fasl")
(#x835d17044d678b006abd8ae1e5213609 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xa4ff0b9f21bf73e70c6d400ff2574e3c . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x0ece19a29a4f5f9a30498ce7cd1d1495 . "./code.cg2js/cg-plot-widget.fasl")
(#x67eeb7fad78b3c2dc66046ac6011273b . "./code.cg2js/cg-dev.fasl")
(#x03fb09f014e61aac83f3406f523efe14 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x0afe52175f3947624ebbc14f27fb4ceb . "./code.cg2js/cg-tab-control.fasl")
(#xc1346b8a1875983e5d23991fee046a06 . "./code.cg2js/cg-fill-texture.fasl")
(#x914694ee91c793decd90dea5e8b131d4 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x525aae79578bdf52b122e4dbc1396c5b . "./code.cg2js/cg-trackbar.fasl")
(#xa6ac9a32c7625d20b3e7a3d85836c205 . "./code.cg2js/cg-nodes.fasl")
(#x00898e0cf80410daa9ee5932b14065cd . "./code.cg2js/cg-common-control.fasl")
(#x345d25c43f2b0d95d083b6702b58f3aa . "./code.cg2js/cg-list-view.fasl")
(#xdc65fbd3408746d290e2cd3b0391ba55 . "./code.cg2js/cg-rich-edit.fasl")
(#xc76c8fdbe46407fd25d1ea1c6d182dc4 . "./code.cg2js/cg-project-window.fasl")
(#xe0c18dbbe216666ddc8f287cf8648b3b . "./code.cg2js/cg-item-list.fasl")
(#xc0c9faf83dc08b9fcecd357325adc464 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x196edc795f644516498f5b54737f6f1d . "./code.cg2js/cg-get-position.fasl")
(#xd68d76ec192d32a0309548497ca96fcd . "./code.cg2js/cg-bitmap-pane.fasl")
(#x3c8b0c52e085cce5e3c992b7d0429181 . "./code.cg2js/cg-drawable.fasl")
(#x06dda2c5ea3cbebf8ef0f07bffa53d64 . "./code.cg2js/cg-lettered-menu.fasl")
(#x5bb85248364888cdb717a9738472ea3c . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xc035473a265dd95b6f278f1c49fb8a13 . "./code.cg2js/cg-html-dialog.fasl")
(#x5b57e835c1feeb5f1c9cf39047909de6 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xa86b293dea78ba7dc4456f6b9bacaae1 . "./code.cg2js/cg-utility-dialog.fasl")
(#xb04dcc056989458a20c02a404866e0c1 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x28649b749cb6b8b634a5ec91f546f07e . "./code.cg2js/cg-property.fasl")
(#xf8468236903dd1eca9db3b1d2c25db44 . "./code.cg2js/cg-menu.fasl")
(#x570550be29e663f2b0729fd751f7317c . "./code.cg2js/cg-clipboard.fasl")
(#x62a44b1c3fcde33fee81ea1837ae2ad6 . "./code.cg2js/cg-toggling-widget.fasl")
(#xa3acef885b03149fe901e12491326284 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xa460e4d5826e5ea71d9ab6553838b68a . "./code.cg2js/cg-template-string.fasl")
(#xa56547aa6fd47bff1817161aaba4c18b . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x194abd155ba414f25020ac4710038e74 . "./code.cg2js/cg-os-window.fasl")
(#xf7917f4004769176f74069cc5dc8c9ee . "./code.cg2js/cg-grid-widget.fasl")
(#x0ea88d1954cff1fb26ffe7e854903232 . "./code.cg2js/cg-picture-widget.fasl")
(#x4b1b3491d007318f09cdbf9b7ff32194 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x4d96c9bf3ae931c422ea838d19c690d3 . "./code.cg2js/cg-static-text.fasl")
(#x73c72bf26066b386e936848209d0dcd4 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x8c1682f3e175c1b4071afa1584ae09df . "./code.cg2js/cg-text-widget.fasl")
(#x45208af918bfdc9a09d75544ec5dc73c . "./code.cg2js/cg-calendar.fasl")
(#x209d1872c6cc5d690444339b79b9db5b . "./code.cg2js/cg-check-box.fasl")
(#xa60e21514f398fd0905a2518a0325cad . "./code.cg2js/cg-acache.fasl")
(#x1d4a1f2a9ce21892e6dee3f3fb8312a9 . "./code.cg2js/cg-wrap-string.fasl")
(#x0c9199408ef23090144a2d4dec91a969 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x4b78090661c5f7de873187c969a79892 . "./code.cg2js/cg-font-dialog.fasl")
(#x9b92f944ca8f4cb1a7583f1e1b6a9927 . "./code.cg2js/cg-outline.fasl")
(#x172650e3def2a83befd353a1830a76b0 . "./code.cg2js/cg-shortcut-menu.fasl")
(#xb0121120cb51d51d8a8446a270233a6f . "./code.cg2js/cg-status-bar.fasl")
(#x0b3b5852d889a634aa6acaa063bad543 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x39445f25fa71f27b22faa27e4094360a . "./code.cg2js/cg-hotspot.fasl")
(#x1accce425cb523029216ef69ee237ff6 . "./code.cg2js/cg-scaling-stream.fasl")
(#x7b7041906bb372a551e1d7e5d2c90754 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x36b0ad4ee88ebbcd24f2a4c5dcbeb41b . "./code.cg2js/cg-file-dialog.fasl")
(#x2a1ff6559d20f4667c24e83611608bdd . "./code.cg2js/cg-color-dialog.fasl")
(#xd28023f3051f28ff73f3552a302cb290 . "./code.cg2js/cg-get-pixmap.fasl")
(#x88572cb273734afb63e271911026327c . "./code.cg2js/cg-object-editor.fasl")
(#x31a7b77f7a9e7897d21cf1b9158ca7bb . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xaf16d2fc12b7b2725b9912694a36ca97 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x7cea4b89c790db40ec9677ec07196e63 . "./code.cg2js/cg-pixmap.fasl")
(#xcfcf128f95c03a88de5619b0278f6f46 . "./code.cg2js/cg-intersect.fasl")
(#x0770e3983e5f30bfaf410f254dc93005 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x900c7758fc9ebab05f84d591cc8b6f74 . "./code.cg2js/cg-icon.fasl")
(#x9bebba50363056beef0c5b99386e8b6a . "./code.cg2js/cg-yes-no-string.fasl")
(#xc4ce0a7b079e4c2457bc33655a062f82 . "./code.cg2js/cg-text-or-combo.fasl")
(#x4bf53fcf04b070dd859181502d812cff . "./code.cg2js/cg.fasl")
(#x5798b3140ae68247b1fd3fe0e552ff16 . "./code.cg2js/cg-dialog-item.fasl")
(#x657177af6cfcb1fcf3d4aa623903ecb7 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x7691bd4e8612c6f0e5aaad482601af15 . "./code.cg2js/cg-caret.fasl")
(#x64312b3d79ff230aa19ac18b2bcd433c . "./code.cg2js/cg-editable-text.fasl")
(#xf639d64b05c15583113b79478500f77b . "./code.cg2js/cg-choose-printer.fasl")
(#xbedcbb85ee3a99b9555c7baa92fbd675 . "./code.cg2js/cg-yes-no-list.fasl")
(#x766f299c5b1b1250f5f2b62ef6237c7b . "./code.cg2js/cg-intersect-posbox.fasl")
(#xa2eb318b7efd38128f2dcc70ee27337c . "./code.cg2js/cg-tooltip.fasl")
(#x7f27f9167919c2c4daa71811b33a41ee . "./code.cg2js/cg-class-slot-grid.fasl")
(#x837642b4190a4bedef03f8fb308f307f . "./code.cg2js/cg-combo-box.fasl")
(#x58bcedc5224fba0fc3c1ec623300ae72 . "./code.cg2js/cg-curve.fasl")
(#xf6c4b2e6c6b4c3348f2aacfef004aa51 . "./code.cg2js/cg-web-browser.fasl")
(#x7e6638633a79df07adbb1508f5cd4549 . "./code.cg2js/cg-printing.fasl")
(#xebc77de998f09cb12f0d83938e189023 . "./code.cg2js/cg-lisp-widget.fasl")
(#x33326b43112e6979fe8207646795df01 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x730809c20eb7b16447b3861e12dd1614 . "./code.cg2js/cg-palette.fasl")
(#xaede64fb371320842582bcb45751258d . "./code.cg2js/cg-os-widget.fasl")
(#x6481411c0a2c197ae2f3f645b48cab4f . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x5cc36612e82041d8129f4e5346938b6f . "./code.cg2js/cg-pixmap-printing.fasl")
(#x8412fa12a6129affc9aa2f4c846e010f . "./code.cg2js/cg-button.fasl")
(#x71c5cdafde05d5fb6ba2f18fdead71cd . "./code.cg2js/cg-edit-in-place.fasl")
(#x3989114ae2f0004916fcc148889c9e98 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xf9a58666c92bd0a3555a27c08a298fb5 . "./code.cg2js/cg-comtab.fasl")
(#x39ad8329e4fa64ff1ac40d0f23762fdf . "./code.cg2js/cg-string-dialog.fasl")
(#xac72e23529a4354d8e2f29699834901d . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xba0be69e13a682ae0a68128d9e9f5423 . "./code.cg2js/cg-up-down-control.fasl")
(#x9ffbea05cabab5b3bd553587f22474c7 . "./code.cg2js/cg-layout.fasl")
(#x59d618c0301d0fd8f3717bd67fe2bfc9 . "./code.cg2js/cg-chart-widget.fasl")
(#x3a3cb00ab2dacff943b4f7b81990840c . "./code.cg2js/cg-lisp-text.fasl")
(#xb60dc22e3f297f33844bb68d6cc36cca . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x79c71453b057feaa81f1af4b08ef656e . "./code.cg2js/cg-progress-indicator.fasl")
(#x34539935af745bc9c8a7edc035d0e030 . "./code.idejs/ide-inspector.fasl")
(#x7ae3f45a616afd80deaa673c64b76c19 . "./code.idejs/ide-grapher.fasl")
(#xf5cf136bf7b021ffc1cafb4b17d33aa6 . "./code.idejs/ide-base.fasl")
(#x7e567883dbd8e1b4eead0552760d454b . "./code.idejs/ide-keyshort.fasl")
(#x2331a9c1305105f1f7788f42e6da44cb . "./code.idejs/ide-dev.fasl")
(#xbb0589f8bfe5e05dbb5bdb327f5dad39 . "./code.idejs/ide-class-browser.fasl")
(#x246b03541de5895c8b2250aae133a86d . "./code.idejs/ide-package-list.fasl")
(#x2bed4186eb3cfe80726261cda6015429 . "./code.idejs/ide-intro.fasl")
(#x51d23c76958f221763a8ccc031c77462 . "./code.idejs/ide-class-grapher.fasl")
(#x4c5419f4d8d8b3233b73ace266d8a3cb . "./code.idejs/ide-window-list.fasl")
(#xf7db1734344588913c92a8ed77478f48 . "./code.idejs/ide-find-definitions.fasl")
(#xe3841954e17b5c6c329ce65c40cf7314 . "./code.idejs/ide-trace.fasl")
(#x8c4e464365c96f8896feccd71ad53767 . "./code.idejs/ide-editor.fasl")
(#x6268fb7afb290032a3936be5eb887a46 . "./code.idejs/ide-patch-dialog.fasl")
(#x606cf4ac29b8befa9a978727029141a6 . "./code.idejs/ide-project.fasl")
(#xab6aca45878955fcead91251f3a9c94a . "./code.idejs/ide.fasl")
(#x52af73e92f9572aa08ebdacc55ced9df . "./code.idejs/ide-apropos.fasl")
(#xb25d915240a0ae16635aba7248b757ab . "./code.idejs/ide-acache.fasl")
(#x68602ea4fc18e4d3c9512ed72f9619c1 . "./code.idejs/ide-clipboard.fasl")
(#x28455f8c284ec43d96987d0e2b839967 . "./code.idejs/ide-process-browser.fasl")
(#xdb15ca35b11ebcf914ceb2f35679750f . "./code.idejs/ide-find-in-files.fasl")
(#x1aae59c1099910be5ce0e23a74287e70 . "./code.idejs/ide-form.fasl")
(#xe933a40f1b5d8c7735b3943a6ba9cb5b . "./code.idejs/ide-navigator.fasl")
(#x49a17b9a618997e974ff2e9af0f2eb06 . "./cgjs.html")
(#x44f169492307df5920f609d11cc1a34c . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
